import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import DualListSelectCommon from '@data-driven-forms/common/dual-list-select';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import { Grid, Row, Column, Button, FormGroup, Search, StructuredListWrapper, StructuredListRow, StructuredListBody, StructuredListCell, TooltipIcon } from 'carbon-components-react';
import { CheckmarkFilled16, ChevronRight32, ChevronLeft32, CaretSortDown32, CaretSortUp32 } from '@carbon/icons-react';
import { buildLabel } from '../prepare-props';
var useStyles = createUseStyles({
  dualList: {
    maxHeight: 500,
    overflow: 'auto',
    display: 'block',
    marginBottom: 0
  },
  dualListBody: {
    width: '100%',
    display: 'inline-table'
  },
  buttonWrapper: {
    flexDirection: 'column',
    padding: '8px !important',
    paddingTop: '8px !important',
    button: {
      width: '100%',
      maxWidth: '100%',
      '@media (max-width: 1055px)': {
        svg: {
          transform: 'rotate(90deg)'
        }
      }
    },
    '& button:not(:last-child)': {
      marginBottom: 8
    }
  },
  toolbar: {
    display: 'flex'
  },
  tooltipButton: {
    background: '#c2c1c1 !important'
  }
});

var EmptyList = function EmptyList(_ref) {
  var message = _ref.message;
  return /*#__PURE__*/React.createElement(StructuredListWrapper, null, /*#__PURE__*/React.createElement(StructuredListBody, null, /*#__PURE__*/React.createElement(StructuredListRow, null, /*#__PURE__*/React.createElement(StructuredListCell, null, message))));
};

var List = function List(_ref2) {
  var options = _ref2.options,
      selectedValues = _ref2.selectedValues,
      handleOptionsClick = _ref2.handleOptionsClick,
      noTitle = _ref2.noTitle,
      ListProps = _ref2.ListProps,
      BodyProps = _ref2.BodyProps;

  var _useStyles = useStyles(),
      dualList = _useStyles.dualList,
      dualListBody = _useStyles.dualListBody;

  return options.length > 0 ? /*#__PURE__*/React.createElement(StructuredListWrapper, _extends({
    selection: true
  }, ListProps, {
    className: clsx(dualList, ListProps.className)
  }), /*#__PURE__*/React.createElement(StructuredListBody, _extends({}, BodyProps, {
    className: clsx(dualListBody, BodyProps.className)
  }), options.map(function (_ref3) {
    var value = _ref3.value,
        label = _ref3.label,
        ListRowProps = _ref3.ListRowProps,
        ListCellProps = _ref3.ListCellProps,
        GridProps = _ref3.GridProps,
        RowProps = _ref3.RowProps,
        LabelProps = _ref3.LabelProps,
        CheckmarkProps = _ref3.CheckmarkProps;
    return /*#__PURE__*/React.createElement(StructuredListRow, _extends({
      key: value
    }, ListRowProps, {
      onClick: function onClick(e) {
        return handleOptionsClick(_objectSpread(_objectSpread({}, e), {}, {
          ctrlKey: true
        }), value);
      }
    }), /*#__PURE__*/React.createElement(StructuredListCell, ListCellProps, /*#__PURE__*/React.createElement(Grid, GridProps, /*#__PURE__*/React.createElement(Row, _extends({
      narrow: true
    }, RowProps), /*#__PURE__*/React.createElement(Column, _extends({
      sm: 3
    }, LabelProps), label), /*#__PURE__*/React.createElement(Column, _extends({
      sm: 1
    }, CheckmarkProps), selectedValues.includes(value) && /*#__PURE__*/React.createElement(CheckmarkFilled16, null))))));
  }))) : /*#__PURE__*/React.createElement(EmptyList, {
    message: noTitle
  });
};

var Toolbar = function Toolbar(_ref4) {
  var sortTitle = _ref4.sortTitle,
      onFilter = _ref4.onFilter,
      onSort = _ref4.onSort,
      sortDirection = _ref4.sortDirection,
      placeholder = _ref4.placeholder,
      ToolbarProps = _ref4.ToolbarProps,
      SearchProps = _ref4.SearchProps,
      SortProps = _ref4.SortProps;

  var _useStyles2 = useStyles(),
      toolbar = _useStyles2.toolbar,
      tooltipButton = _useStyles2.tooltipButton;

  return /*#__PURE__*/React.createElement("div", _extends({}, ToolbarProps, {
    className: clsx(toolbar, ToolbarProps.className)
  }), /*#__PURE__*/React.createElement(Search, _extends({
    onChange: function onChange(e) {
      return onFilter(e.target.value);
    },
    labelText: "",
    placeholder: placeholder
  }, SearchProps)), /*#__PURE__*/React.createElement(TooltipIcon, _extends({
    onClick: onSort,
    tooltipText: sortTitle
  }, SortProps, {
    className: clsx(tooltipButton, SortProps.className)
  }), sortDirection ? /*#__PURE__*/React.createElement(CaretSortDown32, null) : /*#__PURE__*/React.createElement(CaretSortUp32, null)));
};

var isEmpty = function isEmpty(array) {
  return array.length === 0;
};

var DualListSelectInner = function DualListSelectInner(_ref5) {
  var leftValues = _ref5.leftValues,
      handleOptionsClick = _ref5.handleOptionsClick,
      rightValues = _ref5.rightValues,
      handleValuesClick = _ref5.handleValuesClick,
      handleMoveRight = _ref5.handleMoveRight,
      handleClearLeftValues = _ref5.handleClearLeftValues,
      handleMoveLeft = _ref5.handleMoveLeft,
      handleClearRightValues = _ref5.handleClearRightValues,
      state = _ref5.state,
      filterOptions = _ref5.filterOptions,
      filterValues = _ref5.filterValues,
      sortOptions = _ref5.sortOptions,
      sortValues = _ref5.sortValues,
      LeftTitleProps = _ref5.LeftTitleProps,
      RightTitleProps = _ref5.RightTitleProps,
      label = _ref5.label,
      isRequired = _ref5.isRequired,
      _ref5$noOptionsTitle = _ref5.noOptionsTitle,
      noOptionsTitle = _ref5$noOptionsTitle === void 0 ? 'No option available' : _ref5$noOptionsTitle,
      _ref5$noValueTitle = _ref5.noValueTitle,
      noValueTitle = _ref5$noValueTitle === void 0 ? 'No option selected' : _ref5$noValueTitle,
      _ref5$leftTitle = _ref5.leftTitle,
      leftTitle = _ref5$leftTitle === void 0 ? 'Options' : _ref5$leftTitle,
      _ref5$rightTitle = _ref5.rightTitle,
      rightTitle = _ref5$rightTitle === void 0 ? 'Selected' : _ref5$rightTitle,
      _ref5$LeftTitleElemen = _ref5.LeftTitleElement,
      LeftTitleElement = _ref5$LeftTitleElemen === void 0 ? 'h6' : _ref5$LeftTitleElemen,
      _ref5$RightTitleEleme = _ref5.RightTitleElement,
      RightTitleElement = _ref5$RightTitleEleme === void 0 ? 'h6' : _ref5$RightTitleEleme,
      _ref5$moveLeftTitle = _ref5.moveLeftTitle,
      moveLeftTitle = _ref5$moveLeftTitle === void 0 ? 'Remove' : _ref5$moveLeftTitle,
      _ref5$moveRightTitle = _ref5.moveRightTitle,
      moveRightTitle = _ref5$moveRightTitle === void 0 ? 'Add' : _ref5$moveRightTitle,
      _ref5$moveAllLeftTitl = _ref5.moveAllLeftTitle,
      moveAllLeftTitle = _ref5$moveAllLeftTitl === void 0 ? 'Remove All' : _ref5$moveAllLeftTitl,
      _ref5$moveAllRightTit = _ref5.moveAllRightTitle,
      moveAllRightTitle = _ref5$moveAllRightTit === void 0 ? 'Add All' : _ref5$moveAllRightTit,
      _ref5$filterOptionsTi = _ref5.filterOptionsTitle,
      filterOptionsTitle = _ref5$filterOptionsTi === void 0 ? 'Filter options' : _ref5$filterOptionsTi,
      _ref5$filterValuesTit = _ref5.filterValuesTitle,
      filterValuesTitle = _ref5$filterValuesTit === void 0 ? 'Filter values' : _ref5$filterValuesTit,
      _ref5$sortOptionsTitl = _ref5.sortOptionsTitle,
      sortOptionsTitle = _ref5$sortOptionsTitl === void 0 ? 'Sort options' : _ref5$sortOptionsTitl,
      _ref5$sortValuesTitle = _ref5.sortValuesTitle,
      sortValuesTitle = _ref5$sortValuesTitle === void 0 ? 'Sort values' : _ref5$sortValuesTitle,
      _ref5$filterOptionsTe = _ref5.filterOptionsText,
      filterOptionsText = _ref5$filterOptionsTe === void 0 ? 'Remove your filter to see all options' : _ref5$filterOptionsTe,
      _ref5$filterValueText = _ref5.filterValueText,
      filterValueText = _ref5$filterValueText === void 0 ? 'Remove your filter to see all selected' : _ref5$filterValueText,
      _ref5$FormGroupProps = _ref5.FormGroupProps,
      FormGroupProps = _ref5$FormGroupProps === void 0 ? {} : _ref5$FormGroupProps,
      _ref5$GridProps = _ref5.GridProps,
      GridProps = _ref5$GridProps === void 0 ? {} : _ref5$GridProps,
      _ref5$RowProps = _ref5.RowProps,
      RowProps = _ref5$RowProps === void 0 ? {} : _ref5$RowProps,
      _ref5$OptionsColumnPr = _ref5.OptionsColumnProps,
      OptionsColumnProps = _ref5$OptionsColumnPr === void 0 ? {} : _ref5$OptionsColumnPr,
      _ref5$ButtonColumnPro = _ref5.ButtonColumnProps,
      ButtonColumnProps = _ref5$ButtonColumnPro === void 0 ? {} : _ref5$ButtonColumnPro,
      _ref5$ValuesColumnPro = _ref5.ValuesColumnProps,
      ValuesColumnProps = _ref5$ValuesColumnPro === void 0 ? {} : _ref5$ValuesColumnPro,
      _ref5$AddButtonProps = _ref5.AddButtonProps,
      AddButtonProps = _ref5$AddButtonProps === void 0 ? {} : _ref5$AddButtonProps,
      _ref5$AddAllButtonPro = _ref5.AddAllButtonProps,
      AddAllButtonProps = _ref5$AddAllButtonPro === void 0 ? {} : _ref5$AddAllButtonPro,
      _ref5$RemoveButtonPro = _ref5.RemoveButtonProps,
      RemoveButtonProps = _ref5$RemoveButtonPro === void 0 ? {} : _ref5$RemoveButtonPro,
      _ref5$RemoveAllButton = _ref5.RemoveAllButtonProps,
      RemoveAllButtonProps = _ref5$RemoveAllButton === void 0 ? {} : _ref5$RemoveAllButton,
      _ref5$LeftToolbarProp = _ref5.LeftToolbarProps,
      LeftToolbarProps = _ref5$LeftToolbarProp === void 0 ? {} : _ref5$LeftToolbarProp,
      _ref5$RightToolbarPro = _ref5.RightToolbarProps,
      RightToolbarProps = _ref5$RightToolbarPro === void 0 ? {} : _ref5$RightToolbarPro,
      _ref5$LeftSearchProps = _ref5.LeftSearchProps,
      LeftSearchProps = _ref5$LeftSearchProps === void 0 ? {} : _ref5$LeftSearchProps,
      _ref5$RightSearchProp = _ref5.RightSearchProps,
      RightSearchProps = _ref5$RightSearchProp === void 0 ? {} : _ref5$RightSearchProp,
      _ref5$LeftSortProps = _ref5.LeftSortProps,
      LeftSortProps = _ref5$LeftSortProps === void 0 ? {} : _ref5$LeftSortProps,
      _ref5$RightSortProps = _ref5.RightSortProps,
      RightSortProps = _ref5$RightSortProps === void 0 ? {} : _ref5$RightSortProps,
      _ref5$LeftListProps = _ref5.LeftListProps,
      LeftListProps = _ref5$LeftListProps === void 0 ? {} : _ref5$LeftListProps,
      _ref5$LeftBodyProps = _ref5.LeftBodyProps,
      LeftBodyProps = _ref5$LeftBodyProps === void 0 ? {} : _ref5$LeftBodyProps,
      _ref5$RightListProps = _ref5.RightListProps,
      RightListProps = _ref5$RightListProps === void 0 ? {} : _ref5$RightListProps,
      _ref5$RightBodyProps = _ref5.RightBodyProps,
      RightBodyProps = _ref5$RightBodyProps === void 0 ? {} : _ref5$RightBodyProps;

  var _useStyles3 = useStyles(),
      buttonWrapper = _useStyles3.buttonWrapper;

  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    legendText: buildLabel(label || '', isRequired)
  }, FormGroupProps), /*#__PURE__*/React.createElement(Grid, GridProps, /*#__PURE__*/React.createElement(Row, _extends({
    condensed: true
  }, RowProps), /*#__PURE__*/React.createElement(Column, _extends({
    sm: 4,
    md: 8,
    lg: 5
  }, OptionsColumnProps), /*#__PURE__*/React.createElement(LeftTitleElement, LeftTitleProps, leftTitle), /*#__PURE__*/React.createElement(Toolbar, {
    onFilter: filterOptions,
    placeholder: filterOptionsTitle,
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    sortTitle: sortOptionsTitle,
    ToolbarProps: LeftToolbarProps,
    SearchProps: LeftSearchProps,
    SortProps: LeftSortProps
  }), /*#__PURE__*/React.createElement(List, {
    ListProps: LeftListProps,
    BodyProps: LeftBodyProps,
    options: leftValues,
    selectedValues: state.selectedLeftValues,
    handleOptionsClick: handleOptionsClick,
    noTitle: state.filterOptions ? filterOptionsText : noOptionsTitle
  })), /*#__PURE__*/React.createElement(Column, _extends({
    sm: 4,
    md: 8,
    lg: 2
  }, ButtonColumnProps, {
    className: clsx(buttonWrapper, ButtonColumnProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-right",
    renderIcon: ChevronRight32,
    onClick: handleMoveRight,
    disabled: isEmpty(state.selectedLeftValues)
  }, AddButtonProps), moveRightTitle), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-all-right",
    onClick: handleClearLeftValues,
    disabled: isEmpty(leftValues)
  }, AddAllButtonProps), moveAllRightTitle), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-all-left",
    onClick: handleClearRightValues,
    disabled: isEmpty(rightValues)
  }, RemoveAllButtonProps), moveAllLeftTitle), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-left",
    renderIcon: ChevronLeft32,
    onClick: handleMoveLeft,
    disabled: isEmpty(state.selectedRightValues)
  }, RemoveButtonProps), moveLeftTitle)), /*#__PURE__*/React.createElement(Column, _extends({
    sm: 4,
    md: 8,
    lg: 5
  }, ValuesColumnProps), /*#__PURE__*/React.createElement(RightTitleElement, RightTitleProps, rightTitle), /*#__PURE__*/React.createElement(Toolbar, {
    onFilter: filterValues,
    placeholder: filterValuesTitle,
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    sortTitle: sortValuesTitle,
    ToolbarProps: RightToolbarProps,
    SearchProps: RightSearchProps,
    SortProps: RightSortProps
  }), /*#__PURE__*/React.createElement(List, {
    ListProps: RightListProps,
    BodyProps: RightBodyProps,
    options: rightValues,
    selectedValues: state.selectedRightValues,
    handleOptionsClick: handleValuesClick,
    noTitle: state.filterValue ? filterValueText : noValueTitle
  })))));
};

var DualListSelect = function DualListSelect(props) {
  return /*#__PURE__*/React.createElement(DualListSelectCommon, _extends({}, props, {
    DualListSelect: DualListSelectInner
  }));
};

export default DualListSelect;